@@ -30,6 +30,8 @@ OC.L10N.register(
     "Share Calendar" : "Partajează calendarul",
     "Shared" : "Partajat",
     "WebDAV address for subscriptions" : "WebDAV adresa pentru abonamente",
+    "Email sent." : "Mesajul a fost expediat.",
+    "Could not send your email." : "Nu am putut trimite emailul tău.",
     "group" : "grup",
     "Details" : "Detalii",
     "Attendees" : "Participanți",
@@ -84,6 +86,7 @@ OC.L10N.register(
     "{calendar} shared by {owner}" : "{calendar} partajat de {owner}",
     "Please enter a valid WebCal-URL" : "Vă rugăm să introduceți o adresă URL WebCal validă",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Eroare severă în proxy webcal. Vă rugăm să contactați administratorul pentru mai multe informații.",
+    "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
     "Title of the Event" : "Numele evenimentului",
     "Starts" : "Începe",
     "Ends" : "Se termină",
@@ -123,9 +126,9 @@ OC.L10N.register(
     "New Subscription" : "Abonament nou",
     "Go back" : "Înapoi",
     "Go forward" : "Inainte",
-    "Calendar does not exist" : "Calendarul nu exista",
+    "Calendar does not exist" : "Calendarul nu există",
     "Maybe you got a wrong link or the calendar was unshared?" : "Linkul e greșit sau calendarul nu a fost partajat?",
-    "Edit event" : "Modifica eveniment",
+    "Edit event" : "Modifică eveniment",
     "Delete Event" : "Șterge evenimentul",
     "Save Event" : "Salvează evenimentul",
     "Time" : "Timp",
@@ -150,7 +153,7 @@ OC.L10N.register(
     "Analyzing calendar" : "Se analizează calendarul",
     "The file contains objects incompatible with the selected calendar" : "Fișierul conține obiecte incompatibile cu calendarul selectat",
     "New calendar" : "Calendar nou",
-    "File is empty" : "File is empty",
+    "File is empty" : "Fișierul este gol",
     "Import scheduled" : "Import programat",
     "%s shared the calendar <strong>%s</strong> with you" : "%sa partajat calendarul <strong>%s</strong> cu tine",
     "Embed" : "Integra",
