@@ -12,8 +12,8 @@ OC.L10N.register(
     "Too many redirects. Aborting ..." : "Zaznanih je preveč preusmeritev. Opravilo je prekinjeno ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Oddaljeni strežnik nam ni dovolil dostopa koledarja(HTTP {%s} napaka)",
     "Error connecting to remote server" : "Napaka pri povezovanju na strežnik",
-    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Napaka med zahtevanjem virov na strežniku. To je lahko povezano z napako certifikata",
-    "Error requesting resource on remote server" : "Napaka med zahtevanjem virov na strežniku",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Napaka med zahtevo dostopa do vira na oddaljenem strežniku. Morda je problem v neskladnosti potrdila za dostop.",
+    "Error requesting resource on remote server" : "Napaka med zahtevo dostopa do vira na oddaljenem strežniku",
     "Individual" : "Posamezno",
     "Group" : "Skupina",
     "Resource" : "Vir",
